you said there was nothing in the world that could stop it

{interactive slug="binary-cards" type="whole-page" text="true" thumbnail="interactives/binary-cards/img/binarycards.png"}

I had a bad feeling

And darling...
